Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(142)

Unified Diff: tests/corelib/date_time5_test.dart

Issue 11770004: Rename Date to DateTime. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments and keep Backwards-compatibility class Date. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/corelib/date_time4_test.dart ('k') | tests/corelib/date_time6_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/corelib/date_time5_test.dart
diff --git a/tests/corelib/date_time5_test.dart b/tests/corelib/date_time5_test.dart
index aa2109e0b241f14def930cb6f030496902a08cd6..10448e966e89f506970959616e838217347a2722 100644
--- a/tests/corelib/date_time5_test.dart
+++ b/tests/corelib/date_time5_test.dart
@@ -2,10 +2,10 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// Test Date constructor with optional arguments.
main() {
- var d = new Date(2012);
+ var d = new DateTime(2012);
Expect.equals(2012, d.year);
Expect.equals(1, d.month);
Expect.equals(1, d.day);
@@ -14,7 +14,7 @@ main() {
Expect.equals(0, d.second);
Expect.equals(0, d.millisecond);
- d = new Date(2012, 1, 28);
+ d = new DateTime(2012, 1, 28);
Expect.equals(2012, d.year);
Expect.equals(1, d.month);
Expect.equals(28, d.day);
@@ -23,7 +23,7 @@ main() {
Expect.equals(0, d.second);
Expect.equals(0, d.millisecond);
- d = new Date(1970, 3);
+ d = new DateTime(1970, 3);
Expect.equals(1970, d.year);
Expect.equals(3, d.month);
Expect.equals(1, d.day);
@@ -32,7 +32,7 @@ main() {
Expect.equals(0, d.second);
Expect.equals(0, d.millisecond);
- d = new Date(1970, 3, 1, 11);
+ d = new DateTime(1970, 3, 1, 11);
Expect.equals(1970, d.year);
Expect.equals(3, d.month);
Expect.equals(1, d.day);
@@ -41,7 +41,7 @@ main() {
Expect.equals(0, d.second);
Expect.equals(0, d.millisecond);
- d = new Date(0, 12, 24, 0, 12);
+ d = new DateTime(0, 12, 24, 0, 12);
Expect.equals(0, d.year);
Expect.equals(12, d.month);
Expect.equals(24, d.day);
@@ -50,7 +50,7 @@ main() {
Expect.equals(0, d.second);
Expect.equals(0, d.millisecond);
- d = new Date(-1, 2, 2, 3, 0, 0, 4);
+ d = new DateTime(-1, 2, 2, 3, 0, 0, 4);
Expect.equals(-1, d.year);
Expect.equals(2, d.month);
Expect.equals(2, d.day);
@@ -59,7 +59,7 @@ main() {
Expect.equals(0, d.second);
Expect.equals(4, d.millisecond);
- d = new Date(-1, 2, 2, 3, 0, 4);
+ d = new DateTime(-1, 2, 2, 3, 0, 4);
Expect.equals(-1, d.year);
Expect.equals(2, d.month);
Expect.equals(2, d.day);
@@ -68,7 +68,7 @@ main() {
Expect.equals(4, d.second);
Expect.equals(0, d.millisecond);
- d = new Date(2012, 5, 15, 13, 21, 33, 12);
+ d = new DateTime(2012, 5, 15, 13, 21, 33, 12);
Expect.equals(2012, d.year);
Expect.equals(5, d.month);
Expect.equals(15, d.day);
@@ -2,10 +2,10 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Test Date constructor with optional arguments.
+// Test DateTime constructor with optional arguments.
main() {
« no previous file with comments | « tests/corelib/date_time4_test.dart ('k') | tests/corelib/date_time6_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698